#!/bin/bash
# filename: filecheck 
# Used to check file modifications in real time
# Usage example
# filecheck <filename> <period>
# filename - existing file with at least read permitions
# period - interval in seconds if none continuus
#
# Author Hristo Benev foxb@abv.bg
# History
# V 0.1 30 aug 2006
# 	Development started - Hristo Benev
#	Sleep command is required to do a pause between checks
#	wc - line count
#	cut - get appropriate values
#	ls - to get file information
#	tail - to show lines added
# 	WARNING:It suitable just if lines are added (log files)

# Declarations
Version="0.1"
DefaultPeriod=10

# Functions
PrintUsage ()
{
	echo
	echo "Usage:"
	echo
	echo "  filecheck <filename> [period]"
	echo
	echo "filecheck - realtime file monitoring"
	echo "Version=$Version"
	echo
	echo "At least fielname is obligatory"
	echo "    filename - existing file"
	echo "    period - checking interval, $DefaultPeriod seconds by default"
	echo "    -h or --help - display this and exit"
}
# Checks timestamp
CheckTime ()
{
Time=`ls -l --time-style=full-iso $FileName|cut -f 8 --delimiter=" "`
}
# Check for correct command paramethers

if [ $# -eq 0 ] || [ $# -gt 2 ] || [ $1 == "-h" ] || [ $1 == "--help" ]
then
	PrintUsage
	exit 1
else
# File name is first
FileName=$1
# Period is second
Period=$2
# set default period if no param or not digit
if [ -z $Period ] || !([[ $Period =~ [0-9] ]])
then
echo "Warning: Period:$Period INVALID using default $DefaultPeriod "
Period=$DefaultPeriod
fi
# Check file existance
	if [ ! -f $FileName ]
	then
		echo "ERROR:File $FileName DOES NOT exist"
		exit 1
	fi
# Check user rigths
	if [ ! -r $FileName ]
	then
		echo "ERROR:File $FileName cannot be read from You"
		exit 1
	fi
# Check file
	echo "Checking file:$FileName Use ^C to stop"
	CheckTime
	OldTime=$Time
	OldLines=`wc -l $FileName|cut -f 1 --delimiter=" "`
	while [ 1 ] # infinite loop
	do
		echo "test interval $Period seconds"
		CheckTime
		NewTime=$Time
		echo $Time
		sleep $Period
		if [ $NewTime == $OldTime ]
		then
			echo "OK"
		else
			echo "Modified"
			echo
			NewLines=`wc -l $FileName|cut -f 1 --delimiter=" "`
			Lines=$[NewLines-OldLines]
			#echo $NewLines $OldLines
# Show Added lines
			tail --lines=$Lines $FileName
# Reset values
			OldTime=$NewTime
			OldLine=$NewLines
		fi
	done
fi
exit 0
